# ㊑ KABUKA
![](https://github.com/sdanaipat/kabuka/.github/workflows/main.yml/badge.svg)

A simple Python library to get latest stock price from Yahoo! Finance.

## Installation
---
```bash
pip install kabuka
```

## Usage
---
### Python
```python
from kabuka import get_latest_price

latest_price = get_latest_price("AAPL")
```
### CLI
----
```bash
kabuka AAPL
```

## License
----
MIT